diff framework/Document.h @ 53:de2b3c6479c8

* Introduce new Transform class which contains data necessary to describe the context for a plugin -- the plugin's name and output, the step/block size etc (formerly spread across ExecutionContext and TransformFactory). Other code hasn't been updated to use this yet. * Rename existing Transform stuff to Transformers (because they run Transforms) I'm still not 100% sure about this change, don't rely on it.
author Chris Cannam
date Mon, 05 Nov 2007 15:31:06 +0000
parents 43ad8d909e28
children a798f5e6fc5e
line wrap: on
line diff
--- a/framework/Document.h	Fri Nov 02 14:12:17 2007 +0000
+++ b/framework/Document.h	Mon Nov 05 15:31:06 2007 +0000
@@ -17,8 +17,8 @@
 #define _DOCUMENT_H_
 
 #include "layer/LayerFactory.h"
-#include "plugin/transform/Transform.h"
-#include "plugin/transform/PluginTransform.h"
+#include "plugin/transform/Transformer.h"
+#include "plugin/transform/PluginTransformer.h"
 #include "base/Command.h"
 
 #include <map>
@@ -44,8 +44,8 @@
  * requirement to remember where the data came from or how to
  * regenerate it.
  * 
  *  - Any number of Model objects that were generated by a Transform
  * such as FeatureExtractionPluginTransform.  For these, we also
  * record the source model and the name of the transform used to
  * generate the model so that we can regenerate it (potentially
  * from a different source) on demand.
@@ -106,16 +106,16 @@
      * by a transform layer _must_ be registered with the document
      * using addDerivedModel below.
      */
-    Layer *createDerivedLayer(LayerFactory::LayerType, TransformId);
+    Layer *createDerivedLayer(LayerFactory::LayerType, TransformerId);
 
     /**
      * Create and return a suitable layer for the given transform,
      * running the transform and associating the resulting model with
      * the new layer.
      */
-    Layer *createDerivedLayer(TransformId,
+    Layer *createDerivedLayer(TransformerId,
                               Model *inputModel, 
-                              const PluginTransform::ExecutionContext &context,
+                              const PluginTransformer::ExecutionContext &context,
                               QString configurationXml);
 
     /**
@@ -143,15 +143,15 @@
      */
     const WaveFileModel *getMainModel() const { return m_mainModel; }
 
-    std::vector<Model *> getTransformInputModels();
+    std::vector<Model *> getTransformerInputModels();
 
     /**
      * Add a derived model associated with the given transform,
      * running the transform and returning the resulting model.
      */
-    Model *addDerivedModel(TransformId transform,
+    Model *addDerivedModel(TransformerId transform,
                            Model *inputModel,
-                           const PluginTransform::ExecutionContext &context,
+                           const PluginTransformer::ExecutionContext &context,
                            QString configurationXml);
 
     /**
@@ -159,9 +159,9 @@
      * is necessary to register any derived model that was not created
      * by the document using createDerivedModel or createDerivedLayer.
      */
-    void addDerivedModel(TransformId,
+    void addDerivedModel(TransformerId,
                          Model *inputModel,
-                         const PluginTransform::ExecutionContext &context,
+                         const PluginTransformer::ExecutionContext &context,
                          Model *outputModelToAdd,
                          QString configurationXml);
 
@@ -267,8 +267,8 @@
 	// transform involved but the (target) model has been modified
 	// since being generated from it.
 	const Model *source;
-	TransformId transform;
-        PluginTransform::ExecutionContext context;
+	TransformerId transform;
+        PluginTransformer::ExecutionContext context;
         QString configurationXml;
 
 	// Count of the number of layers using this model.
@@ -44,8 +44,8 @@
  * regenerate it.
  * 
- *  - Any number of Model objects that were generated by a Transform
- * such as FeatureExtractionPluginTransform.  For these, we also
+ *  - Any number of Model objects that were generated by a Transformer
+ * such as FeatureExtractionPluginTransformer.  For these, we also
  * record the source model and the name of the transform used to
  * generate the model so that we can regenerate it (potentially